imx_lib_extract_bin() {
	local bin_path="$BIN_DIR/$BIN_NAME"
	if [[ -f "$bin_path" ]]; then
		chmod +x "$bin_path"
		(
			cd "$PACKAGE_DIR"
			"$bin_path" "$EXTRACT_BIN_OPT"
		)
	elif [[ -d "$bin_path" ]]; then
		cp -r "$bin_path" "$PACKAGE_DIR"
	fi
}

imx_lib_download_bin() {
	if ! [[ -f "$BIN_DIR/$1" ]]; then
		wget "$MIRROR_SITE/$1" -P "$BIN_DIR"
	fi
}

# contents of debian/changelog file
imx_lib_changelog() {
	cat << EOF
$IMX_BIN_PACKAGE (${IMX_BIN_VERSION}-1) experimental; urgency=low

  * This package was created with at-imxlibpackage.

 -- $MAINTAINER_NAME <$MAINTAINER_EMAIL>  $(date -R)
EOF
}

# contents of debian/copyright file
imx_lib_copyright() {
	cat << EOF
Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/

Files: *
Copyright: Copyright 2014 Verisilicon(Beijing) Co.,Ltd. All Rights Reserved.
License: LA_OPT_NXP_Software_License
EOF

	find "$PACKAGE_DIR" -type f -iname COPYING -exec iconv -t UTF-8 {} + |
		sed -e 's/^$/\./g; s/^/ /g'
	echo
}

imx_lib_build() {
	( cd "$TARGET" && dpkg-buildpackage -uc -us -aarm64 ) ||
		error_exit "buildpackage failed."

	cp "$PACKAGE_DIR/${IMX_BIN_PACKAGE}_"*.deb "$DEB_DIR" ||
		error_exit "copy failed, no package produced?"

	rm -rf "$PACKAGE_DIR/$IMX_BIN_PACKAGE"*
}

imx_lib_check_depends() {
	local missing_packages=( )
	for pkg in "${BUILD_DEPENDS[@]}";
	do
		if ! dpkg -s "$pkg" > /dev/null 2>&1; then
			missing_packages+=( "$pkg" )
		fi
	done
	if [[ "${#missing_packages[@]}" != 0 ]]; then
		cat >&2 << EOF
Error: missing the following packages: ${missing_packages[*]}
Try: sudo apt install ${missing_packages[*]}
EOF
		FAILED=true
		exit 1
	fi
}

# build debian package
imx_lib_package_run() {
	if ! [[ -f "$DEB_DIR/${IMX_BIN_PACKAGE}_${IMX_BIN_VERSION}-1_arm64.deb" ]]; then
		imx_lib_extract_bin
		TARGET="$PACKAGE_DIR/${BIN_NAME%.*}"
		DEBIAN_DIR="$TARGET/debian"
		install -d -m 755 "$DEBIAN_DIR"

		imx_lib_changelog > "$DEBIAN_DIR/changelog"
		"$imx_bin_control" > "$DEBIAN_DIR/control"
		imx_lib_copyright > "$DEBIAN_DIR/copyright"
		"$imx_bin_install" > "$DEBIAN_DIR/$IMX_BIN_PACKAGE.install.arm64"
		"$imx_bin_rules" > "$DEBIAN_DIR/rules"
		chmod +x "$DEBIAN_DIR/rules"
		imx_lib_build
	fi
	sudo apt install "$DEB_DIR/${IMX_BIN_PACKAGE}_${IMX_BIN_VERSION}-1_arm64.deb"
}
